<?php

/**
* Completed Table Controller
* 
* 
*
* @link 		https://entusiastics.com
* @since 		1.0.0
*
* @package 	Entusiastics_Quiz_Game
* @subpackage 	Entusiastics_Quiz_Game/admin/controllers
*/

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class CompletedTableController extends WP_List_Table {

	function __construct(){

		global $status, $page;

		parent::__construct( array(
			'singular'  => __( 'Completado', 'entusiastics-quiz-game' ),
			'plural'    => __( 'Completados', 'entusiastics-quiz-game' ),
			'ajax'      => false
		));

	}

	function no_items() {
		_e('Aún no hay ningú Quizz completado.', 'entusiastics-quiz-game');
	}

	function column_default( $item, $column_name ) {

		switch( $column_name ) {
			case 'id':
			case 'quizz_title':
			case 'created_at':
			return $item[ $column_name ];
			default:
			return print_r( $item, true );
		}

	}

	function get_sortable_columns() {

		$sortable_columns = array(
			'quizz_title'  => array('quizz_title', false),
			'created_at'   => array('created_at', false),
		);
		return $sortable_columns;

	}

	function get_columns(){

		$columns = array(
			'cb'        => '<input type="checkbox" />',
			'id' => __( 'Identificador', 'entusiastics-quiz-game' ),
			'quizz_title' => __( 'Quizz', 'entusiastics-quiz-game' ),
			'created_at' => __('Fecha de creación', 'entusiastics-quiz-game')
		);

		return $columns;

	}

	function usort_reorder( $a, $b ) {
  		// If no sort, default to title
		$orderby = ( ! empty( $_GET['orderby'] ) ) ? $_GET['orderby'] : 'created_at';
  		// If no order, default to asc
		$order = ( ! empty($_GET['order'] ) ) ? $_GET['order'] : 'asc';
  		// Determine sort order
		$result = strcmp( $a[$orderby], $b[$orderby] );
  		// Send final sort direction to usort
		return ( $order === 'asc' ) ? $result : -$result;
	}


	function column_id($item){

		$see_word = __('Ver', 'entusiastics-quiz-game');
		$delete_word = __('Eliminar', 'entusiastics-quiz-game');

		$actions = array(
			'see' => sprintf('<a href="admin.php?page=entusiastics-quiz-game-completed&action=index&id=%d&quiz_id=%d">%s</a>', $item['id'], $item['quizz_id'], $see_word ),
			'delete' => sprintf('<a href="admin.php?page=entusiastics-quiz-game-completed&action=delete&id=%d">%s</a>', $item['id'], $delete_word)
		);

		return sprintf('%1$s %2$s', $item['id'], $this->row_actions($actions));
	}

	function get_bulk_actions() {
		$actions = array(
			'delete'    => __('Borrar', 'entusiastics-quiz-game')
		);
		return $actions;
	}

	public function process_bulk_action() {

        // Security check!
		if ( isset( $_POST['_wpnonce'] ) && ! empty( $_POST['_wpnonce'] ) ) {

			$nonce  = filter_input( INPUT_POST, '_wpnonce', FILTER_SANITIZE_STRING );
			$action = 'bulk-' . $this->_args['plural'];

			if ( ! wp_verify_nonce( $nonce, $action ) )
				wp_die( 'Nope! Security check failed!' );

		}

		$action = $this->current_action();

		switch ( $action ) {

			case 'delete':

			$completados = $_POST['completados'];
			$_completed = new Completed();
			$_completed->bulkDelete($completados);
			
			break;
			default:
			return;
			break;
		}

		return;
	}

	function column_cb($item) {
		return sprintf(
			'<input type="checkbox" name="completados[]" value="%s" />', $item['id']
		);    
	}

	function prepare_items() {

		$search_term = "";
		$action = "";
		$quiz_id = "";

		if(isset($_REQUEST["action"])){ 
			$action = $_REQUEST["action"];
		}

		if(isset($_REQUEST["quizz_id"])){ 
			$quiz_id = $_REQUEST["quizz_id"];
		}

		// Get the search param
		if(isset($_REQUEST["s"])){ 
			$search_term = $_REQUEST["s"];
		}

		$data = $this->getQuizzesCompletedList($search_term);

		if($action != "" && $quiz_id != "") {
			$data =  $this->getQuizzesCompletedFilteredList($search_term, $quiz_id);
		}

		$completed = $this->object_to_array($data);

		$columns  = $this->get_columns();
		$hidden   = array();
		$sortable = $this->get_sortable_columns();
		$this->_column_headers = $this->get_column_info();
		usort( $completed, array( &$this, 'usort_reorder' ) );

		$per_page = $this->get_items_per_page( 'completed_per_page', 50 );
		$current_page = $this->get_pagenum();
		$total_items = count($completed);

		$found_data = array_slice( $completed, ( ( $current_page - 1 ) * $per_page ), $per_page );

		$this->set_pagination_args( array(
			'total_items' => $total_items,
			'per_page' => $per_page
		));

		$this->process_bulk_action();

		$this->items = $found_data;
	}

	function object_to_array($data)
	{
		if (is_array($data) || is_object($data))
		{
			$result = array();
			foreach ($data as $key => $value)
			{
				$result[$key] = $this->object_to_array($value);
			}
			return $result;
		}
		return $data;
	}

	static function render_quizzes_completed_list(){

		$filter = '';

		$completed_list_table = new CompletedTableController();

		$completed_list_table->prepare_items();

		include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH."admin/partials/entusiastics-quiz-game-completed-list.php");
	}

	function getQuizzesCompletedList($search_term){

		global $wpdb;

		$order_by = 'created_at';

		if($search_term != "") {
			// select completed filter search params
			$sql = $wpdb->prepare("SELECT c.*,q.title as quizz_title,q.id as quizz_id FROM ".ENTUSIASTICS_QUIZ_GAME_COMPLETED." c INNER JOIN ".ENTUSIASTICS_QUIZ_GAME_QUIZZES." q ON c.quiz_id=q.id WHERE quizz_title LIKE %2\$s OR created_at LIKE %2\$s ORDER BY %1$s DESC", $order_by, "%".$search_term."%");		

		} else {	
			// select completed
			$sql = $wpdb->prepare("SELECT c.*,q.title as quizz_title,q.id as quizz_id FROM ".ENTUSIASTICS_QUIZ_GAME_COMPLETED." c INNER JOIN ".ENTUSIASTICS_QUIZ_GAME_QUIZZES." q ON c.quiz_id=q.id ORDER BY %s DESC", $order_by);
		}

		$completed = $wpdb->get_results($sql);
		
		return $completed;
	}

	function getQuizzesCompletedFilteredList($search_term, $quiz_id){

		global $wpdb;

		$order_by = 'created_at';

		if($search_term != "") {
			// select completed filter search params
			$sql = $wpdb->prepare("SELECT c.*,q.title as quizz_title,q.id as quizz_id FROM ".ENTUSIASTICS_QUIZ_GAME_COMPLETED." c INNER JOIN ".ENTUSIASTICS_QUIZ_GAME_QUIZZES." q ON c.quiz_id=q.id WHERE quizz_id LIKE %1$d AND quizz_title LIKE %2$s OR created_at LIKE %2$s ORDER BY %3$s DESC", $quiz_id, "%".$search_term."%", $order_by);		

		} else {	
			// select completed
			$sql = $wpdb->prepare("SELECT c.*,q.title as quizz_title,q.id as quizz_id FROM ".ENTUSIASTICS_QUIZ_GAME_COMPLETED." c INNER JOIN ".ENTUSIASTICS_QUIZ_GAME_QUIZZES." q ON c.quiz_id=q.id WHERE quizz_id=%d ORDER BY %s DESC", $quiz_id, $order_by);
		}

		$completed = $wpdb->get_results($sql);
		
		return $completed;
	}

} //class


